@@ -121,8 +121,8 @@ class Radar(Line):
         self._box.xmin = self._box.ymin = 0
         self._box.xmax = self._box.ymax = self._rmax = max(self._values)
 
-        self._y_pos = self._pos(
-            self._box.ymin, self._box.ymax, self.y_scale, max_scale=8
+        self._y_pos = self._compute_scale(
+            self._box.ymin, self._box.ymax, max_scale=8
         ) if not self.y_labels else map(int, self.y_labels)
         self._x_labels = self.x_labels and zip(self.x_labels, self._x_pos)
         self._y_labels = zip(map(self.format, self._y_pos), self._y_pos)
